package Net::ISC::DHCPd::Leases::Lease;

=head1 NAME

Net::ISC::DHCPd::Leases::Lease - Lease object

=head1 SYNOPSIS

See L<Net::ISC::DHCPd::Leases>.

=head1 DESCRIPTION

This class does the role L<Net::ISC::DHCPd::Role::Lease>.

=cut

use Moose;

with qw/Net::ISC::DHCPd::Role::Lease/;

=head1 ATTRIBUTES

=head1 COPYRIGHT & LICENSE

=head1 AUTHOR

See L<Net::ISC::DHCPd>.

=cut

1;
